@@ -7,6 +7,7 @@ from typing import Dict, List, Union
 from assertpy import assert_that
 
 from deepdriver.sdk.chart.chart import Chart
+from deepdriver.sdk.data_types.artifactInfo import ArtifactInfo
 from deepdriver.sdk.data_types.image import Image
 from deepdriver.sdk.data_types.run import get_run
 from deepdriver.sdk.data_types.table import Table
@@ -58,19 +59,17 @@ class ArtifactEntry:
         self.local_path = local_path
 
     # ArtifactEntry 객체를 기반으로 파일 업로드 수행
-    def upload(self, upload_type: str, root_path: str, run_id: int, artifact_id: int, last_file_yn: str, team_name: str,
-               exp_name: str, run_name: str, artifact_name: str, artifact_type: str, artifact_digest: str,
-               entry_list: List[grpc_ArtifactEntry], file_index: int) -> bool:
+    def upload(self, upload_type: str, root_path: str, run_id: int, team_name: str,
+               exp_name: str, run_name: str, arti_info: ArtifactInfo , file_index: int) -> bool:
         assert_that(root_path).is_not_none()
         assert_that(run_id).is_not_none()
-        assert_that(artifact_id).is_not_none()
-        assert_that(last_file_yn).is_not_none()
-        assert_that(artifact_digest).is_not_none()
-        assert_that(entry_list).is_not_none()
+        # assert_that(artifact_id).is_not_none()
+        # assert_that(last_file_yn).is_not_none()
+        # assert_that(artifact_digest).is_not_none()
+        # assert_that(entry_list).is_not_none()
         if self.local_path:
-            return interface.upload_file(upload_type, self.local_path, root_path, self.path, run_id, artifact_id,
-                                         last_file_yn, team_name, exp_name, run_name, artifact_name, artifact_type,
-                                         artifact_digest, self.digest, entry_list, file_index=file_index)
+            return interface.upload_file(upload_type=upload_type, local_path=self.local_path, root_path=root_path,path=self.path, run_id=run_id,teamName=team_name, expName=exp_name, run_name=run_name,
+                                         entry_digest=self.digest,  arti_info=arti_info, file_index=file_index)
         else:
             return True
 
@@ -303,9 +302,11 @@ class Artifacts:
                 upload_type = "ARTI_FILES"
 
             file_index = next((file_index for (file_index, d) in enumerate(entry_dict.keys()) if d == entry.path), None)
-            succeeded = entry.upload(upload_type, root_path, self.run.run_id, self.id, last_file_yn, self.run.team_name,
-                                     self.run.exp_name, self.run.run_name, self.name, self.type, artifact_digest,
-                                     entry_list, file_index=file_index)
+            artiInfo =ArtifactInfo(artifact_id=self.id, artifact_name= self.name, artifact_type=self.type, last_file_yn= last_file_yn,artifact_digest= artifact_digest, entry_list= entry_list)
+
+            succeeded = entry.upload(upload_type, root_path, self.run.run_id, self.run.team_name,
+                                     self.run.exp_name, self.run.run_name, artiInfo,
+                                     file_index=file_index)
 
             if not succeeded:
                 return False
