@@ -7,7 +7,10 @@ import urllib3
 from deepdriver.sdk import util
 from deepdriver import logger
 import deepdriver.version as version
+from deepdriver.sdk.data_types.artifactInfo import ArtifactInfo
+from deepdriver.sdk.interface.file_upload import Progress
 from deepdriver.sdk.security.crypto import Aes
+from deepdriver.sdk.interface.grpc_interface_pb2 import ArtifactEntry
 
 URL_CHECK_EMAIL = "/api/public/login/email"
 URL_ID_LOGIN = "/api/public/login/pass"
@@ -16,6 +19,7 @@ URL_CREATE = "/api/client/experiment/create"
 URL_CREATE_HPO = "/api/client/experiment/create/hpo"
 URL_GET_HPO = "/api/client/experiment/get/hpo"
 URL_UPLOAD_LOG = "/api/client/run/log/upload"
+URL_UPLOAD_FILE = "/api/client/file/upload"
 URL_SEND_ALERT = "/api/client/run/alert/send"
 URL_UPDATE_CONFIG = "/api/client/run/config/update"
 URL_FINISH = "/api/client/run/finish"
@@ -164,6 +168,20 @@ def upload_log(http_host:str, run_id: int , exp_name: str, team_name: str , step
     logger.debug("upload_log() response : " + rsp["message"])
     return rsp
 
+def upload_file(http_host:str, upload_type: str, local_path: str, root_path: str, path: str, run_id: int,
+                 teamName: str, expName: str, run_name: str,
+                entry_digest: str, arti_info: ArtifactInfo, file_index: int) -> Dict:
+    url = parse_result_wraaper(http_host, URL_UPLOAD_FILE)
+    with open(path, "rb") as f:
+        progress = Progress(f,)
+        for chunk in progress:
+            chunk_data = chunk
+            rsp=  post(
+                url, data=chunk_data
+            )
+            logger.debug("upload_file() response : " + rsp["message"])
+
+    return rsp
 
 def update_config(http_host:str, run_id: int , exp_name: str, team_name: str , items: list):
     item_list = [{"key": k, "value": v} for (k, v) in items] if items else []
