@@ -11,6 +11,7 @@ import grpc
 
 from deepdriver import logger
 from deepdriver.sdk import util
+from deepdriver.sdk.data_types.artifactInfo import ArtifactInfo
 from deepdriver.sdk.interface import http_interface
 from deepdriver.sdk.interface.grpc_interface_pb2 import *
 from deepdriver.sdk.interface.grpc_interface_pb2_grpc import ResourceStub
@@ -188,9 +189,8 @@ def upload_log(run_id: int, team_name: str, exp_name: str, log_step: int, item_d
 CHUNK_SIZE = 4* 1024 * 1024  # 8MB
 
 
-def load_file(upload_type: str, local_path: str, root_path: str, path: str, run_id: int, artifact_id: int,
-              last_file_yn: str, team_name: str, exp_name: str, run_name: str, artifact_name: str, artifact_type: str,
-              artifact_digest: str, entry_digest: str, entry_list: List[ArtifactEntry],
+def load_file(upload_type: str, local_path: str, root_path: str, path: str, run_id: int,team_name: str, exp_name: str, run_name: str,
+             entry_digest: str, arti_info:ArtifactInfo,
               file_index: int) -> UploadFileRequest:
     if sys.platform.startswith('win32'):
         # 윈도우인 경우 Path Seperator를 리눅스 형식으로 강제로 변경함
@@ -205,19 +205,19 @@ def load_file(upload_type: str, local_path: str, root_path: str, path: str, run_
                 root_path=root_path,
             )
         )),
-        artifact_id=artifact_id,
+        artifact_id=arti_info.artifact_id,
         run_id=run_id,
-        artifactName=artifact_name,
-        artifactType=artifact_type,
+        artifactName=arti_info.artifact_name,
+        artifactType=arti_info.artifact_type,
         digest=entry_digest,
-        last_file_yn=last_file_yn,
+        last_file_yn=arti_info.last_file_yn,
         authorization=f"Bearer {http_interface.get_jwt_key()}",
         teamName=team_name,
         expName=exp_name,
         runName=run_name,
         total_file_info=TotalFileInfo(
-            digest=artifact_digest,
-            entry=entry_list,
+            digest=arti_info.artifact_digest,
+            entry=arti_info.entry_list,
         ),
     )
     with open(local_path, "rb") as file:
@@ -228,41 +228,44 @@ def load_file(upload_type: str, local_path: str, root_path: str, path: str, run_
             chunk_bytes = file.read(CHUNK_SIZE)
             uploaded_size += len(chunk_bytes)
             util.print_progress(uploaded_size, total_size, f'Uploading: [{local_path}]',
-                                f"[{file_index + 1}/{1 if len(entry_list) == 0 else len(entry_list)}")
+                                f"[{file_index + 1}/{1 if len(arti_info.entry_list) == 0 else len(arti_info.entry_list)}")
             if len(chunk_bytes) == 0:  # Reached EOF
                 util.print_progress(total_size, total_size, f'Uploading: [{local_path}]',
-                                    f"[{file_index + 1}/{1 if len(entry_list) == 0 else len(entry_list)}]")  # 100%
+                                    f"[{file_index + 1}/{1 if len(arti_info.entry_list) == 0 else len(arti_info.entry_list)}]")  # 100%
                 return
             yield UploadFileRequest(
                 file=FileRecord(file=FileItem(
                     contents=chunk_bytes
                 )),
-                artifact_id=artifact_id,
+                artifact_id=arti_info.artifact_id,
                 run_id=run_id,
-                artifactName=artifact_name,
-                artifactType=artifact_type,
+                artifactName=arti_info.artifact_name,
+                artifactType=arti_info.artifact_type,
                 digest=entry_digest,
-                last_file_yn=last_file_yn,
+                last_file_yn=arti_info.last_file_yn,
                 authorization=f"Bearer {http_interface.get_jwt_key()}",
                 teamName=team_name,
                 expName=exp_name,
                 runName=run_name,
                 total_file_info=TotalFileInfo(
-                    digest=artifact_digest,
-                    entry=entry_list,
+                    digest=arti_info.artifact_digest,
+                    entry=arti_info.entry_list,
                 ),
             )
 
 
-def upload_file(upload_type: str, local_path: str, root_path: str, path: str, run_id: int, artifact_id: int,
-                last_file_yn: str, teamName: str, expName: str, run_name: str, artifact_name: str, artifact_type: str,
-                artifact_digest: str, entry_digest: str, entry_list: List[ArtifactEntry], file_index: int) -> bool:
+def upload_file(upload_type: str, local_path: str, root_path: str, path: str, run_id: int,
+                 teamName: str, expName: str, run_name: str,
+                entry_digest: str, arti_info: ArtifactInfo, file_index: int) -> bool:
     logger.debug(
         f"upload_file() : {locals()}")
-
-    rsp: UploadFileResponse = get_stub().upload_file(
-        load_file(upload_type, local_path, root_path, path, run_id, artifact_id, last_file_yn, teamName, expName,
-                  run_name, artifact_name, artifact_type, artifact_digest, entry_digest, entry_list, file_index))
+    if get_use_grpc():
+        rsp: UploadFileResponse = get_stub().upload_file(
+            load_file(upload_type, local_path, root_path, path, run_id, teamName, expName,
+                      run_name,  entry_digest, arti_info, file_index))
+    else:
+        http_interface.upload_file(upload_type, local_path, root_path, path, run_id, teamName, expName,
+                      run_name,  entry_digest, arti_info, file_index)
     return rsp.rsp_result.result == "success"
 
 
